@@ -556,7 +556,7 @@ function archive_store:set(username, key, new_value, new_when, new_with)
 		if new_value then
 			table.insert(setf, '"type" = ?')
 			table.insert(setf, '"value" = ?')
-			local t, value = serialize(new_value);
+			local t, value = assert(serialize(new_value));
 			table.insert(args, 1, t);
 			table.insert(args, 2, value);
 		end
@@ -995,6 +995,8 @@ function module.load()
 					engine:execute("PRAGMA fullfsync=1;")
 				end
 
+				engine:execute(("PRAGMA busy_timeout=%d;"):format(module:get_option_integer("sqlite_busy_timeout_ms", 1000, 0)));
+
 				for row in engine:select[[PRAGMA journal_mode;]] do
 					journal_mode = row[1];
 				end
